const styleTableId = "#styleTable";
const styleModalId = "#styleFormModal";


// region Init Module

function initMessageStylesModule() {
    initializeDataTable(
        styleTableId,
        [
            {
                title: "Name",
                data: "name",
                render: renderEditColumn
            },
            {
                title: "Is Embed",
                data: "is_embed",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Is Hyperlinked",
                data: "is_hyperlinked",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Author",
                data: "show_author",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Timestamp",
                data: "show_timestamp",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Images",
                data: "show_images",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Fetch Images",
                data: "fetch_images",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Title Mutator",
                data: "title_mutator"
            },
            {
                title: "Description Mutator",
                data: "description_mutator"
            }
        ]
    );
};


// region Load Data

$(document).on("selectedServerChange", async function() {
    await loadMessageStyleData();
});

$(document).on("doDataLoad", async function() {
    await loadMessageStyleData();
});

async function loadMessageStyleData() {
    if (!selectedServer) {
        return;
    }

    setTableFilter(styleTableId, "server", selectedServer.id);
    await loadTableData(styleTableId, "/api/message-styles/", "GET");
}


// region New/Edit Modal

$(styleTableId).closest(".js-tableBody").siblings(".js-tableFilters").on("click", ".table-new-btn", async function() {
    await openDataModal(styleModalId, -1);
});

$(styleTableId).on("click", ".edit-modal", async function() {
    let id = $(styleTableId).DataTable().row($(this).closest("tr")).data().id;
    await openDataModal(styleModalId, id, `/api/message-styles/${id}/`);
});

$(styleModalId).on("submit", async function(event) {
    event.preventDefault();
    await onModalSubmit(
        $(styleModalId),
        $(styleTableId),
        "/api/message-styles/"
    );
});


// region Load Mutator Options

$(document).ready(async function() {
    await loadMutatorOptions();
});

async function loadMutatorOptions() {
    let $inputs = $(styleModalId).find('[data-field="title_mutator"], [data-field="description_mutator"]');

    $inputs.val("").change();
    $inputs.prop("disabled", true);

    $inputs.find("option").each(function() {
        if ($(this).val()) {
            $(this).remove();
        }
    });

    const data = await ajaxRequest("/api/message-mutators/?page_size=25", "GET");
    data.results.forEach(mutator => {
        $inputs.append($(
            "<option>",
            {text: mutator.name, value: mutator.id}
        ));
    });

    $inputs.prop("disabled", false);
}
